@@ -24,7 +24,12 @@ from ..utils import represents, endpoints, AsyncFetcher
 
 
 class AuctionTag:
-    """Represents a dblstats tag object."""
+    """
+    Represents a dblstats tag object.
+
+    :param bot: A collection of tags strings that are linked to bot types.
+    :param server: A collection of tags strings that are linked to server types.
+    """
 
     def __init__(self, bot: List[str], server: List[str]):
         self.bot = bot
@@ -35,11 +40,24 @@ class AuctionTag:
 
 
 class AuctionUser(UserBase):
-    """Represents a Top.gg auction user."""
+    """
+    Represents a Top.gg auction user.
+
+    :param id: The user their discord id
+    :param tag: The user their discord tag (username#discriminator)
+    :param avatar: The user their discord avatar url
+    :param default_avatar: The user their default discord avatar url (calculated by discriminator)
+    :param product: The bot/server name for which the bet is for.
+    :param tag: That associated page for the product.
+    :param list: The list type for the product, this is either bot or server.
+    :param amount: The bet amount in usd.
+    :param outbid: If this bet has been outbid.
+    :param timestamp: When the bet got submitted.
+    :param is_fake: If the bet has been verified as real.
+    """
 
     def __init__(self, id: str, user_tag: str, avatar: str, default_avatar: str, product: str, tag: str, list: str,
                  amount: int, outbid: bool, timestamp: datetime, is_fake: bool):
-        """Creates a Top.gg auction user."""
         super().__init__(id, user_tag, avatar, default_avatar)
         self.product = product
         self.tag = tag
@@ -54,10 +72,14 @@ class AuctionUser(UserBase):
 
 
 class AuctionCurrent:
-    """Represents all current betters."""
+    """
+    Represents all current betters.
+
+    :param bot: A dictionary of which contains a collection of :class AuctionUser: objects which are associated with the tag (as key) in the bot section.
+    :param server: A dictionary of which contains a collection of :class AuctionUser: objects which are associated with the tag (as key) in the server section.
+    """
 
     def __init__(self, bot: Dict[str, List[AuctionUser]], server: Dict[str, List[AuctionUser]]):
-        """Creates a new auction current object."""
         self.bot = bot
         self.server = server
 
@@ -66,7 +88,13 @@ class AuctionCurrent:
 
 
 class Auctions:
-    """An object that can fetch the current Top.gg auctions"""
+    """
+    An object that can fetch the current Top.gg auctions
+
+    :param fetcher: The :class AsyncFetcher: object. (Which will fetch the data from the API)
+
+    :property tags: Returns a cached :class AuctionTag:.
+    """
 
     def __init__(self, fetcher: AsyncFetcher):
         self.__fetcher = fetcher
@@ -75,7 +103,11 @@ class Auctions:
         return represents(self)
 
     async def get_tags(self) -> AuctionTag:
-        """Returns a collection of bot and server tags."""
+        """
+        Fetches the latest tags from the API. This also updates the tags property for this class.
+
+        :return AuctionTag: The latest bot and server tags.
+        """
         tags = await self.__fetcher.get(endpoints.GET_AUCTIONS_TAGS)
         return AuctionTag(tags["bot"], tags["server"])
 
@@ -95,7 +127,11 @@ class Auctions:
         return data
 
     async def get_current(self) -> AuctionCurrent:
-        """Returns a dictionary of all current betters."""
+        """
+        Fetches all current auctions.
+
+        :return AuctionCurrent: The latest auctions.
+        """
         data = await self.__fetcher.get(endpoints.GET_AUCTIONS_CURRENT)
         return AuctionCurrent(self.parse_auction_users(data["bot"].items()),
                               self.parse_auction_users(data["server"].items()))
